@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::License::Custom;
 # ABSTRACT: custom license handler
-$Software::License::Custom::VERSION = '0.104001';
+$Software::License::Custom::VERSION = '0.104002';
 use parent 'Software::License';
 
 use Carp;
@@ -213,7 +213,7 @@ Software::License::Custom - custom license handler
 
 =head1 VERSION
 
-version 0.104001
+version 0.104002
 
 =head1 DESCRIPTION
 
@@ -274,6 +274,15 @@ the end of the file. Example:
 The different formats for specifying the section name in the example
 above are only examples, you're invited to use a consistent approach.
 
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version of
+perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
+but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013.
+
 =head1 METHODS
 
 =head2 new
@@ -352,7 +361,7 @@ Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
