@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::OpenSSL;
-$Software::License::OpenSSL::VERSION = '0.103014';
+$Software::License::OpenSSL::VERSION = '0.104002';
 use parent 'Software::License';
 # ABSTRACT: The OpenSSL License
 
@@ -33,15 +33,24 @@ Software::License::OpenSSL - The OpenSSL License
 
 =head1 VERSION
 
-version 0.103014
+version 0.104002
+
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version of
+perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
+but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
