@@ -4,7 +4,7 @@ use Carp;
 
 package Software::LicenseUtils;
 # ABSTRACT: little useful bits of code for licensey things
-$Software::LicenseUtils::VERSION = '0.103012';
+$Software::LicenseUtils::VERSION = '0.104002';
 use File::Spec;
 use IO::Dir;
 use Module::Load;
@@ -14,14 +14,16 @@ use Module::Load;
 #pod   my @guesses = Software::LicenseUtils->guess_license_from_pod($pm_text);
 #pod
 #pod Given text containing POD, like a .pm file, this method will attempt to guess
-#pod at the license under which the code is available.  This method will either
-#pod a list of Software::License classes (or instances) or false.
+#pod at the license under which the code is available.  This method will return
+#pod either a list of Software::License classes names (as strings) or false.
+#pod
+#pod This method looks for a POD heading like 'license', 'copyright', or 'legal'.
 #pod
 #pod Calling this method in scalar context is a fatal error.
 #pod
 #pod =cut
 
-my $_v = qr/(?:v(?:er(?:sion|\.))(?: |\.)?)/i;
+my $_v = qr/(?:v(?:er(?:sion|\.))?(?: |\.)?)/i;
 my @phrases = (
   "under the same (?:terms|license) as perl $_v?6" => [],
   'under the same (?:terms|license) as (?:the )?perl'    => 'Perl_5',
@@ -32,7 +34,9 @@ my @phrases = (
     $_[0] == 2 ? 'LGPL_2_1' : $_[0] == 3 ? 'LGPL_3_0' : ()
   },
   'GNU (?:lesser|library) (?:general )?public license'  => [ qw(LGPL_2_1 LGPL_3_0) ],
+  '(?:the )?2[-\s]clause (?:Free)?BSD' => 'FreeBSD',
   'BSD license'                => 'BSD',
+  'FreeBSD license'            => 'FreeBSD',
   "Artistic license $_v?(\\d)" => sub { "Artistic_$_[0]_0" },
   'Artistic license'           => [ map { "Artistic_$_\_0" } (1..2) ],
   "LGPL,? $_v?(\\d)"             => sub {
@@ -41,14 +45,24 @@ my @phrases = (
   'LGPL'                       => [ qw(LGPL_2_1 LGPL_3_0) ],
   "GPL,? $_v?(\\d)"              => sub { "GPL_$_[0]" },
   'GPL'                        => [ map { "GPL_$_" } (1..3) ],
+  'FreeBSD'                    => 'FreeBSD',
   'BSD'                        => 'BSD',
   'Artistic'                   => [ map { "Artistic_$_\_0" } (1..2) ],
   'MIT'                        => 'MIT',
+  'has dedicated the work to the Commons' => 'CC0_1_0',
+  'waiving all of his or her rights to the work worldwide under copyright law' => 'CC0_1_0',
+  'has waived all copyright and related or neighboring rights to' => 'CC0_1_0',
+  'apache(?: |-)1.1' => "Apache_1_1",
+  "Apache Software License(\\s)+Version 1.1" => "Apache_1_1",
+  'apache(?: |-)2.0' => "Apache_2_0",
+  "Apache License(\\s)+Version 2.0" => "Apache_2_0",
+  'No license is granted to other entities' => 'None',
 );
 
 my %meta_keys  = ();
 my %meta1_keys = ();
 my %meta2_keys = ();
+my %spdx_expression  = ();
 
 # find all known Software::License::* modules and get identification data
 #
@@ -72,6 +86,9 @@ for my $lib (map { "$_/Software/License" } @INC) {
       $meta1_keys{ $class->meta_name  }{$mod} = undef;
       $meta_keys{  $class->meta2_name }{$mod} = undef;
       $meta2_keys{ $class->meta2_name }{$mod} = undef;
+      if (defined $class->spdx_expression) {
+        $spdx_expression{  $class->spdx_expression   }{$class} = undef;
+      }
       my $name = $class->name;
       unshift @phrases, qr/\Q$name\E/, [$mod];
       if ((my $name_without_space = $name) =~ s/\s+\(.+?\)//) {
@@ -207,7 +224,7 @@ sub new_from_short_name {
   Carp::croak "no license short name specified"
     unless defined $arg->{short_name};
   my $short = delete $arg->{short_name};
-  Carp::croak "Unknow license with short name $short"
+  Carp::croak "Unknown license with short name $short"
     unless $short_name{$short};
 
   my $lic_file = my $lic_class = $short_name{$short} ;
@@ -216,6 +233,36 @@ sub new_from_short_name {
   return $lic_class->new( $arg );
 }
 
+#pod =method new_from_spdx_expression
+#pod
+#pod   my $license_object = Software::LicenseUtils->new_from_spdx_expression( {
+#pod      spdx_expression => 'MPL-2.0',
+#pod      holder => 'X. Ample'
+#pod   }) ;
+#pod
+#pod Create a new L<Software::License> object from the license specified
+#pod with C<spdx_expression>. Some licenses doesn't have an spdx
+#pod identifier (for example L<Software::License::Perl_5>), so you can pass
+#pod spdx identifier but also expressions.
+#pod Known spdx license identifiers are C<BSD>, C<MPL-1.0>.
+#pod
+#pod =cut
+
+sub new_from_spdx_expression {
+  my ( $class, $arg ) = @_;
+
+  Carp::croak "no license spdx name specified"
+    unless defined $arg->{spdx_expression};
+  my $spdx = delete $arg->{spdx_expression};
+  Carp::croak "Unknown license with spdx name $spdx"
+    unless $spdx_expression{$spdx};
+
+  my ($lic_file) = my ($lic_class) = keys %{$spdx_expression{$spdx}} ;
+  $lic_file =~ s!::!/!g;
+  require "$lic_file.pm";
+  return $lic_class->new( $arg );
+}
+
 1;
 
 __END__
@@ -230,7 +277,16 @@ Software::LicenseUtils - little useful bits of code for licensey things
 
 =head1 VERSION
 
-version 0.103012
+version 0.104002
+
+=head1 PERL VERSION
+
+This module is part of CPAN toolchain, or is treated as such.  As such, it
+follows the agreement of the Perl Toolchain Gang to require no newer version of
+perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
+but for now is governed by the L<Lancaster
+Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
+of 2013.
 
 =head1 METHODS
 
@@ -239,8 +295,10 @@ version 0.103012
   my @guesses = Software::LicenseUtils->guess_license_from_pod($pm_text);
 
 Given text containing POD, like a .pm file, this method will attempt to guess
-at the license under which the code is available.  This method will either
-a list of Software::License classes (or instances) or false.
+at the license under which the code is available.  This method will return
+either a list of Software::License classes names (as strings) or false.
+
+This method looks for a POD heading like 'license', 'copyright', or 'legal'.
 
 Calling this method in scalar context is a fatal error.
 
@@ -271,13 +329,26 @@ Create a new L<Software::License> object from the license specified
 with C<short_name>. Known short license names are C<GPL-*>, C<LGPL-*> ,
 C<Artistic> and C<Artistic-*>
 
+=head2 new_from_spdx_expression
+
+  my $license_object = Software::LicenseUtils->new_from_spdx_expression( {
+     spdx_expression => 'MPL-2.0',
+     holder => 'X. Ample'
+  }) ;
+
+Create a new L<Software::License> object from the license specified
+with C<spdx_expression>. Some licenses doesn't have an spdx
+identifier (for example L<Software::License::Perl_5>), so you can pass
+spdx identifier but also expressions.
+Known spdx license identifiers are C<BSD>, C<MPL-1.0>.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
